@@ -1,6 +1,6 @@
 package Server::Control;
 BEGIN {
-  $Server::Control::VERSION = '0.19';
+  $Server::Control::VERSION = '0.20';
 }
 use Capture::Tiny;
 use File::Basename;
@@ -784,7 +784,7 @@ Server::Control -- Flexible apachectl style control for servers
 
 =head1 VERSION
 
-version 0.19
+version 0.20
 
 =head1 SYNOPSIS
 
@@ -862,9 +862,8 @@ L<Server::Control::NetServer> - For L<Net::Server|Net::Server>
 
 =back
 
-There may be other subclasses
-L<http://search.cpan.org/search?query=Server%3A%3AControl&mode=all|available on
-CPAN>.
+There may be other subclasses L<available on
+CPAN|http://search.cpan.org/search?query=Server%3A%3AControl&mode=all>.
 
 =for readme stop
 
@@ -931,7 +930,8 @@ defaults to L</stopstart>.
 =item server_root
 
 Root directory of server, for conf files, log files, etc. This will affect
-defaults of other parameters like I<log_dir>.
+defaults of other parameters like I<log_dir>. You must create this directory,
+it will not be created for you.
 
 =item serverctlrc
 
